==> haskell-vector-hashtables-0.1.2.1-78.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-hashtables
version:              0.1.2.1
visibility:           public
id:                   vector-hashtables-0.1.2.1-F6VKwkE4v4hHCfq9IFjCsv
key:                  vector-hashtables-0.1.2.1-F6VKwkE4v4hHCfq9IFjCsv
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  a35e65f39a241d0945206349e4d6d8ae
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-hashtables-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-hashtables-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-hashtables-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.1-F6VKwkE4v4hHCfq9IFjCsv
depends:
    base-4.18.2.1 hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-hashtables-0.1.2.1-79-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-hashtables.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-hashtables
version:              0.1.2.1
visibility:           public
id:                   vector-hashtables-0.1.2.1-Ao85Na2hSQIAlt0hCbOXZs
key:                  vector-hashtables-0.1.2.1-Ao85Na2hSQIAlt0hCbOXZs
license:              BSD-3-Clause
copyright:            2016-2024 klapaucius, swamp_agr
maintainer:           klapaucius, swamp_agr, ArtemPelenitsyn
author:               klapaucius
homepage:             https://github.com/klapaucius/vector-hashtables#readme
synopsis:             Efficient vector-based mutable hashtables implementation.
description:
    This package provides efficient vector-based hashtable implementation similar to .NET Generic Dictionary implementation (at the time of 2015).

    See "Data.Vector.Hashtables" for documentation.

category:             Data
abi:                  ee42f78c1b57f325e7a67075a963d13d
exposed:              True
exposed-modules:
    Data.Primitive.PrimArray.Utils Data.Vector.Hashtables
    Data.Vector.Hashtables.Internal
    Data.Vector.Hashtables.Internal.Mask

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vector-hashtables-0.1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vector-hashtables-0.1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vector-hashtables-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-hashtables
hs-libraries:         HSvector-hashtables-0.1.2.1-Ao85Na2hSQIAlt0hCbOXZs
depends:
    base-4.18.2.1 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-vector-hashtables/html/vector-hashtables.haddock

haddock-html:         /usr/share/doc/haskell-vector-hashtables/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
